.. aiokef documentation master file, created by
   sphinx-quickstart on Sat Nov  9 13:45:58 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Contents:

   CHANGELOG
   reference/aiokef
